
"""Wrap is a command line utility that runs a wxPython program with
additional runtime-tools, such as PyCrust."""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: wrap.py,v 1.1.2.2 2003/03/11 19:37:33 RD Exp $"
__revision__ = "$Revision: 1.1.2.2 $"[11:-2]

import os
import sys
from wxPython import wx
from crust import CrustFrame as Frame

try:
    True
except NameError:
    True = 1==1
    False = 1==0


def wrap(app):
    wx.wxInitAllImageHandlers()
    frame = Frame()
    frame.SetSize((750, 525))
    frame.Show(True)
    frame.shell.interp.locals['app'] = app
    app.MainLoop()


def main(argv):
    if len(argv) < 2:
        print "Please specify a module name."
        raise SystemExit
    name = argv[1]
    if name[-3:] == '.py':
        name = name[:-3]
    module = __import__(name)
    # Find the App class.
    App = None
    d = module.__dict__
    for item in d.keys():
        try:
            if issubclass(d[item], wx.wxApp):
                App = d[item]
        except (NameError, TypeError):
            pass
    if App is None:
        print "No App class found."
        raise SystemExit
    app = App()
    wrap(app)


if __name__ == '__main__':
    sys.path.insert(0, os.curdir)
    main(sys.argv)



# This file was created automatically by SWIG.
import fontsc

from misc import *
class wxNativeFontInfoPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Init(self, *_args, **_kwargs):
        val = apply(fontsc.wxNativeFontInfo_Init,(self,) + _args, _kwargs)
        return val
    def GetPointSize(self, *_args, **_kwargs):
        val = apply(fontsc.wxNativeFontInfo_GetPointSize,(self,) + _args, _kwargs)
        return val
    def GetStyle(self, *_args, **_kwargs):
        val = apply(fontsc.wxNativeFontInfo_GetStyle,(self,) + _args, _kwargs)
        return val
    def GetWeight(self, *_args, **_kwargs):
        val = apply(fontsc.wxNativeFontInfo_GetWeight,(self,) + _args, _kwargs)
        return val
    def GetUnderlined(self, *_args, **_kwargs):
        val = apply(fontsc.wxNativeFontInfo_GetUnderlined,(self,) + _args, _kwargs)
        return val
    def GetFaceName(self, *_args, **_kwargs):
        val = apply(fontsc.wxNativeFontInfo_GetFaceName,(self,) + _args, _kwargs)
        return val
    def GetFamily(self, *_args, **_kwargs):
        val = apply(fontsc.wxNativeFontInfo_GetFamily,(self,) + _args, _kwargs)
        return val
    def GetEncoding(self, *_args, **_kwargs):
        val = apply(fontsc.wxNativeFontInfo_GetEncoding,(self,) + _args, _kwargs)
        return val
    def SetPointSize(self, *_args, **_kwargs):
        val = apply(fontsc.wxNativeFontInfo_SetPointSize,(self,) + _args, _kwargs)
        return val
    def SetStyle(self, *_args, **_kwargs):
        val = apply(fontsc.wxNativeFontInfo_SetStyle,(self,) + _args, _kwargs)
        return val
    def SetWeight(self, *_args, **_kwargs):
        val = apply(fontsc.wxNativeFontInfo_SetWeight,(self,) + _args, _kwargs)
        return val
    def SetUnderlined(self, *_args, **_kwargs):
        val = apply(fontsc.wxNativeFontInfo_SetUnderlined,(self,) + _args, _kwargs)
        return val
    def SetFaceName(self, *_args, **_kwargs):
        val = apply(fontsc.wxNativeFontInfo_SetFaceName,(self,) + _args, _kwargs)
        return val
    def SetFamily(self, *_args, **_kwargs):
        val = apply(fontsc.wxNativeFontInfo_SetFamily,(self,) + _args, _kwargs)
        return val
    def SetEncoding(self, *_args, **_kwargs):
        val = apply(fontsc.wxNativeFontInfo_SetEncoding,(self,) + _args, _kwargs)
        return val
    def FromString(self, *_args, **_kwargs):
        val = apply(fontsc.wxNativeFontInfo_FromString,(self,) + _args, _kwargs)
        return val
    def ToString(self, *_args, **_kwargs):
        val = apply(fontsc.wxNativeFontInfo_ToString,(self,) + _args, _kwargs)
        return val
    def __str__(self, *_args, **_kwargs):
        val = apply(fontsc.wxNativeFontInfo___str__,(self,) + _args, _kwargs)
        return val
    def FromUserString(self, *_args, **_kwargs):
        val = apply(fontsc.wxNativeFontInfo_FromUserString,(self,) + _args, _kwargs)
        return val
    def ToUserString(self, *_args, **_kwargs):
        val = apply(fontsc.wxNativeFontInfo_ToUserString,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxNativeFontInfo instance at %s>" % (self.this,)
class wxNativeFontInfo(wxNativeFontInfoPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(fontsc.new_wxNativeFontInfo,_args,_kwargs)
        self.thisown = 1




class wxFontMapperPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=fontsc.delete_wxFontMapper):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def GetAltForEncoding(self, *_args, **_kwargs):
        val = apply(fontsc.wxFontMapper_GetAltForEncoding,(self,) + _args, _kwargs)
        return val
    def IsEncodingAvailable(self, *_args, **_kwargs):
        val = apply(fontsc.wxFontMapper_IsEncodingAvailable,(self,) + _args, _kwargs)
        return val
    def CharsetToEncoding(self, *_args, **_kwargs):
        val = apply(fontsc.wxFontMapper_CharsetToEncoding,(self,) + _args, _kwargs)
        return val
    def SetDialogParent(self, *_args, **_kwargs):
        val = apply(fontsc.wxFontMapper_SetDialogParent,(self,) + _args, _kwargs)
        return val
    def SetDialogTitle(self, *_args, **_kwargs):
        val = apply(fontsc.wxFontMapper_SetDialogTitle,(self,) + _args, _kwargs)
        return val
    def SetConfig(self, *_args, **_kwargs):
        val = apply(fontsc.wxFontMapper_SetConfig,(self,) + _args, _kwargs)
        return val
    def SetConfigPath(self, *_args, **_kwargs):
        val = apply(fontsc.wxFontMapper_SetConfigPath,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxFontMapper instance at %s>" % (self.this,)
class wxFontMapper(wxFontMapperPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(fontsc.new_wxFontMapper,_args,_kwargs)
        self.thisown = 1




class wxFontPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def wxFontFromNativeInfoString(self, *_args, **_kwargs):
        val = apply(fontsc.wxFont_wxFontFromNativeInfoString,(self,) + _args, _kwargs)
        if val: val = wxFontPtr(val) ; val.thisown = 1
        return val
    def __del__(self, delfunc=fontsc.delete_wxFont):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def Ok(self, *_args, **_kwargs):
        val = apply(fontsc.wxFont_Ok,(self,) + _args, _kwargs)
        return val
    def GetPointSize(self, *_args, **_kwargs):
        val = apply(fontsc.wxFont_GetPointSize,(self,) + _args, _kwargs)
        return val
    def GetFamily(self, *_args, **_kwargs):
        val = apply(fontsc.wxFont_GetFamily,(self,) + _args, _kwargs)
        return val
    def GetStyle(self, *_args, **_kwargs):
        val = apply(fontsc.wxFont_GetStyle,(self,) + _args, _kwargs)
        return val
    def GetWeight(self, *_args, **_kwargs):
        val = apply(fontsc.wxFont_GetWeight,(self,) + _args, _kwargs)
        return val
    def GetUnderlined(self, *_args, **_kwargs):
        val = apply(fontsc.wxFont_GetUnderlined,(self,) + _args, _kwargs)
        return val
    def GetFaceName(self, *_args, **_kwargs):
        val = apply(fontsc.wxFont_GetFaceName,(self,) + _args, _kwargs)
        return val
    def GetEncoding(self, *_args, **_kwargs):
        val = apply(fontsc.wxFont_GetEncoding,(self,) + _args, _kwargs)
        return val
    def IsFixedWidth(self, *_args, **_kwargs):
        val = apply(fontsc.wxFont_IsFixedWidth,(self,) + _args, _kwargs)
        return val
    def GetNativeFontInfo(self, *_args, **_kwargs):
        val = apply(fontsc.wxFont_GetNativeFontInfo,(self,) + _args, _kwargs)
        if val: val = wxNativeFontInfoPtr(val) 
        return val
    def GetNativeFontInfoDesc(self, *_args, **_kwargs):
        val = apply(fontsc.wxFont_GetNativeFontInfoDesc,(self,) + _args, _kwargs)
        return val
    def GetNativeFontInfoUserDesc(self, *_args, **_kwargs):
        val = apply(fontsc.wxFont_GetNativeFontInfoUserDesc,(self,) + _args, _kwargs)
        return val
    def SetPointSize(self, *_args, **_kwargs):
        val = apply(fontsc.wxFont_SetPointSize,(self,) + _args, _kwargs)
        return val
    def SetFamily(self, *_args, **_kwargs):
        val = apply(fontsc.wxFont_SetFamily,(self,) + _args, _kwargs)
        return val
    def SetStyle(self, *_args, **_kwargs):
        val = apply(fontsc.wxFont_SetStyle,(self,) + _args, _kwargs)
        return val
    def SetWeight(self, *_args, **_kwargs):
        val = apply(fontsc.wxFont_SetWeight,(self,) + _args, _kwargs)
        return val
    def SetFaceName(self, *_args, **_kwargs):
        val = apply(fontsc.wxFont_SetFaceName,(self,) + _args, _kwargs)
        return val
    def SetUnderlined(self, *_args, **_kwargs):
        val = apply(fontsc.wxFont_SetUnderlined,(self,) + _args, _kwargs)
        return val
    def SetEncoding(self, *_args, **_kwargs):
        val = apply(fontsc.wxFont_SetEncoding,(self,) + _args, _kwargs)
        return val
    def SetNativeFontInfo(self, *_args, **_kwargs):
        val = apply(fontsc.wxFont_SetNativeFontInfo,(self,) + _args, _kwargs)
        return val
    def SetNativeFontInfoUserDesc(self, *_args, **_kwargs):
        val = apply(fontsc.wxFont_SetNativeFontInfoUserDesc,(self,) + _args, _kwargs)
        return val
    def GetFamilyString(self, *_args, **_kwargs):
        val = apply(fontsc.wxFont_GetFamilyString,(self,) + _args, _kwargs)
        return val
    def GetStyleString(self, *_args, **_kwargs):
        val = apply(fontsc.wxFont_GetStyleString,(self,) + _args, _kwargs)
        return val
    def GetWeightString(self, *_args, **_kwargs):
        val = apply(fontsc.wxFont_GetWeightString,(self,) + _args, _kwargs)
        return val
    def SetNoAntiAliasing(self, *_args, **_kwargs):
        val = apply(fontsc.wxFont_SetNoAntiAliasing,(self,) + _args, _kwargs)
        return val
    def GetNoAntiAliasing(self, *_args, **_kwargs):
        val = apply(fontsc.wxFont_GetNoAntiAliasing,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxFont instance at %s>" % (self.this,)
class wxFont(wxFontPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(fontsc.new_wxFont,_args,_kwargs)
        self.thisown = 1



def wxFontFromNativeInfo(*_args,**_kwargs):
    val = wxFontPtr(apply(fontsc.new_wxFontFromNativeInfo,_args,_kwargs))
    val.thisown = 1
    return val


class wxFontListPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def AddFont(self, *_args, **_kwargs):
        val = apply(fontsc.wxFontList_AddFont,(self,) + _args, _kwargs)
        return val
    def FindOrCreateFont(self, *_args, **_kwargs):
        val = apply(fontsc.wxFontList_FindOrCreateFont,(self,) + _args, _kwargs)
        if val: val = wxFontPtr(val) 
        return val
    def RemoveFont(self, *_args, **_kwargs):
        val = apply(fontsc.wxFontList_RemoveFont,(self,) + _args, _kwargs)
        return val
    def GetCount(self, *_args, **_kwargs):
        val = apply(fontsc.wxFontList_GetCount,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxFontList instance at %s>" % (self.this,)
class wxFontList(wxFontListPtr):
    def __init__(self,this):
        self.this = this




class wxFontEnumeratorPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=fontsc.delete_wxFontEnumerator):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(fontsc.wxFontEnumerator__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def EnumerateFacenames(self, *_args, **_kwargs):
        val = apply(fontsc.wxFontEnumerator_EnumerateFacenames,(self,) + _args, _kwargs)
        return val
    def EnumerateEncodings(self, *_args, **_kwargs):
        val = apply(fontsc.wxFontEnumerator_EnumerateEncodings,(self,) + _args, _kwargs)
        return val
    def GetEncodings(self, *_args, **_kwargs):
        val = apply(fontsc.wxFontEnumerator_GetEncodings,(self,) + _args, _kwargs)
        return val
    def GetFacenames(self, *_args, **_kwargs):
        val = apply(fontsc.wxFontEnumerator_GetFacenames,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxFontEnumerator instance at %s>" % (self.this,)
class wxFontEnumerator(wxFontEnumeratorPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(fontsc.new_wxFontEnumerator,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxFontEnumerator, 0)




class wxLanguageInfoPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __setattr__(self,name,value):
        if name == "Language" :
            fontsc.wxLanguageInfo_Language_set(self,value)
            return
        if name == "CanonicalName" :
            fontsc.wxLanguageInfo_CanonicalName_set(self,value)
            return
        if name == "Description" :
            fontsc.wxLanguageInfo_Description_set(self,value)
            return
        self.__dict__[name] = value
    def __getattr__(self,name):
        if name == "Language" : 
            return fontsc.wxLanguageInfo_Language_get(self)
        if name == "CanonicalName" : 
            return fontsc.wxLanguageInfo_CanonicalName_get(self)
        if name == "Description" : 
            return fontsc.wxLanguageInfo_Description_get(self)
        raise AttributeError,name
    def __repr__(self):
        return "<C wxLanguageInfo instance at %s>" % (self.this,)
class wxLanguageInfo(wxLanguageInfoPtr):
    def __init__(self,this):
        self.this = this




class wxLocalePtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=fontsc.delete_wxLocale):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def Init1(self, *_args, **_kwargs):
        val = apply(fontsc.wxLocale_Init1,(self,) + _args, _kwargs)
        return val
    def Init2(self, *_args, **_kwargs):
        val = apply(fontsc.wxLocale_Init2,(self,) + _args, _kwargs)
        return val
    def IsOk(self, *_args, **_kwargs):
        val = apply(fontsc.wxLocale_IsOk,(self,) + _args, _kwargs)
        return val
    def GetLocale(self, *_args, **_kwargs):
        val = apply(fontsc.wxLocale_GetLocale,(self,) + _args, _kwargs)
        return val
    def GetLanguage(self, *_args, **_kwargs):
        val = apply(fontsc.wxLocale_GetLanguage,(self,) + _args, _kwargs)
        return val
    def GetSysName(self, *_args, **_kwargs):
        val = apply(fontsc.wxLocale_GetSysName,(self,) + _args, _kwargs)
        return val
    def GetCanonicalName(self, *_args, **_kwargs):
        val = apply(fontsc.wxLocale_GetCanonicalName,(self,) + _args, _kwargs)
        return val
    def AddCatalog(self, *_args, **_kwargs):
        val = apply(fontsc.wxLocale_AddCatalog,(self,) + _args, _kwargs)
        return val
    def IsLoaded(self, *_args, **_kwargs):
        val = apply(fontsc.wxLocale_IsLoaded,(self,) + _args, _kwargs)
        return val
    def GetString(self, *_args, **_kwargs):
        val = apply(fontsc.wxLocale_GetString,(self,) + _args, _kwargs)
        return val
    def GetName(self, *_args, **_kwargs):
        val = apply(fontsc.wxLocale_GetName,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxLocale instance at %s>" % (self.this,)
    
    def Init(self, *_args, **_kwargs):
        if type(_args[0]) in [type(''), type(u'')]:
            val = apply(self.Init1, _args, _kwargs)
        else:
            val = apply(self.Init2, _args, _kwargs)
        return val
    
class wxLocale(wxLocalePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(fontsc.new_wxLocale,_args,_kwargs)
        self.thisown = 1




class wxEncodingConverterPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=fontsc.delete_wxEncodingConverter):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def Init(self, *_args, **_kwargs):
        val = apply(fontsc.wxEncodingConverter_Init,(self,) + _args, _kwargs)
        return val
    def Convert(self, *_args, **_kwargs):
        val = apply(fontsc.wxEncodingConverter_Convert,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxEncodingConverter instance at %s>" % (self.this,)
class wxEncodingConverter(wxEncodingConverterPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(fontsc.new_wxEncodingConverter,_args,_kwargs)
        self.thisown = 1






#-------------- FUNCTION WRAPPERS ------------------

def wxGetLocale(*_args, **_kwargs):
    val = apply(fontsc.wxGetLocale,_args,_kwargs)
    if val: val = wxLocalePtr(val)
    return val

wxGetTranslation = fontsc.wxGetTranslation

def wxFontMapper_Get(*_args, **_kwargs):
    val = apply(fontsc.wxFontMapper_Get,_args,_kwargs)
    if val: val = wxFontMapperPtr(val)
    return val

def wxFontMapper_Set(*_args, **_kwargs):
    val = apply(fontsc.wxFontMapper_Set,_args,_kwargs)
    if val: val = wxFontMapperPtr(val)
    return val

wxFontMapper_GetEncodingName = fontsc.wxFontMapper_GetEncodingName

wxFontMapper_GetEncodingDescription = fontsc.wxFontMapper_GetEncodingDescription

wxFontMapper_GetDefaultConfigPath = fontsc.wxFontMapper_GetDefaultConfigPath

wxFont_GetDefaultEncoding = fontsc.wxFont_GetDefaultEncoding

wxFont_SetDefaultEncoding = fontsc.wxFont_SetDefaultEncoding

wxLocale_GetSystemLanguage = fontsc.wxLocale_GetSystemLanguage

wxLocale_GetSystemEncoding = fontsc.wxLocale_GetSystemEncoding

wxLocale_GetSystemEncodingName = fontsc.wxLocale_GetSystemEncodingName

wxLocale_AddCatalogLookupPathPrefix = fontsc.wxLocale_AddCatalogLookupPathPrefix

def wxLocale_GetLanguageInfo(*_args, **_kwargs):
    val = apply(fontsc.wxLocale_GetLanguageInfo,_args,_kwargs)
    if val: val = wxLanguageInfoPtr(val)
    return val

wxLocale_AddLanguage = fontsc.wxLocale_AddLanguage

wxEncodingConverter_GetPlatformEquivalents = fontsc.wxEncodingConverter_GetPlatformEquivalents

wxEncodingConverter_GetAllEquivalents = fontsc.wxEncodingConverter_GetAllEquivalents



#-------------- VARIABLE WRAPPERS ------------------

wxFONTFAMILY_DEFAULT = fontsc.wxFONTFAMILY_DEFAULT
wxFONTFAMILY_DECORATIVE = fontsc.wxFONTFAMILY_DECORATIVE
wxFONTFAMILY_ROMAN = fontsc.wxFONTFAMILY_ROMAN
wxFONTFAMILY_SCRIPT = fontsc.wxFONTFAMILY_SCRIPT
wxFONTFAMILY_SWISS = fontsc.wxFONTFAMILY_SWISS
wxFONTFAMILY_MODERN = fontsc.wxFONTFAMILY_MODERN
wxFONTFAMILY_TELETYPE = fontsc.wxFONTFAMILY_TELETYPE
wxFONTFAMILY_MAX = fontsc.wxFONTFAMILY_MAX
wxFONTFAMILY_UNKNOWN = fontsc.wxFONTFAMILY_UNKNOWN
wxFONTSTYLE_NORMAL = fontsc.wxFONTSTYLE_NORMAL
wxFONTSTYLE_ITALIC = fontsc.wxFONTSTYLE_ITALIC
wxFONTSTYLE_SLANT = fontsc.wxFONTSTYLE_SLANT
wxFONTSTYLE_MAX = fontsc.wxFONTSTYLE_MAX
wxFONTWEIGHT_NORMAL = fontsc.wxFONTWEIGHT_NORMAL
wxFONTWEIGHT_LIGHT = fontsc.wxFONTWEIGHT_LIGHT
wxFONTWEIGHT_BOLD = fontsc.wxFONTWEIGHT_BOLD
wxFONTWEIGHT_MAX = fontsc.wxFONTWEIGHT_MAX
wxFONTENCODING_SYSTEM = fontsc.wxFONTENCODING_SYSTEM
wxFONTENCODING_DEFAULT = fontsc.wxFONTENCODING_DEFAULT
wxFONTENCODING_ISO8859_1 = fontsc.wxFONTENCODING_ISO8859_1
wxFONTENCODING_ISO8859_2 = fontsc.wxFONTENCODING_ISO8859_2
wxFONTENCODING_ISO8859_3 = fontsc.wxFONTENCODING_ISO8859_3
wxFONTENCODING_ISO8859_4 = fontsc.wxFONTENCODING_ISO8859_4
wxFONTENCODING_ISO8859_5 = fontsc.wxFONTENCODING_ISO8859_5
wxFONTENCODING_ISO8859_6 = fontsc.wxFONTENCODING_ISO8859_6
wxFONTENCODING_ISO8859_7 = fontsc.wxFONTENCODING_ISO8859_7
wxFONTENCODING_ISO8859_8 = fontsc.wxFONTENCODING_ISO8859_8
wxFONTENCODING_ISO8859_9 = fontsc.wxFONTENCODING_ISO8859_9
wxFONTENCODING_ISO8859_10 = fontsc.wxFONTENCODING_ISO8859_10
wxFONTENCODING_ISO8859_11 = fontsc.wxFONTENCODING_ISO8859_11
wxFONTENCODING_ISO8859_12 = fontsc.wxFONTENCODING_ISO8859_12
wxFONTENCODING_ISO8859_13 = fontsc.wxFONTENCODING_ISO8859_13
wxFONTENCODING_ISO8859_14 = fontsc.wxFONTENCODING_ISO8859_14
wxFONTENCODING_ISO8859_15 = fontsc.wxFONTENCODING_ISO8859_15
wxFONTENCODING_ISO8859_MAX = fontsc.wxFONTENCODING_ISO8859_MAX
wxFONTENCODING_KOI8 = fontsc.wxFONTENCODING_KOI8
wxFONTENCODING_ALTERNATIVE = fontsc.wxFONTENCODING_ALTERNATIVE
wxFONTENCODING_BULGARIAN = fontsc.wxFONTENCODING_BULGARIAN
wxFONTENCODING_CP437 = fontsc.wxFONTENCODING_CP437
wxFONTENCODING_CP850 = fontsc.wxFONTENCODING_CP850
wxFONTENCODING_CP852 = fontsc.wxFONTENCODING_CP852
wxFONTENCODING_CP855 = fontsc.wxFONTENCODING_CP855
wxFONTENCODING_CP866 = fontsc.wxFONTENCODING_CP866
wxFONTENCODING_CP874 = fontsc.wxFONTENCODING_CP874
wxFONTENCODING_CP932 = fontsc.wxFONTENCODING_CP932
wxFONTENCODING_CP936 = fontsc.wxFONTENCODING_CP936
wxFONTENCODING_CP949 = fontsc.wxFONTENCODING_CP949
wxFONTENCODING_CP950 = fontsc.wxFONTENCODING_CP950
wxFONTENCODING_CP1250 = fontsc.wxFONTENCODING_CP1250
wxFONTENCODING_CP1251 = fontsc.wxFONTENCODING_CP1251
wxFONTENCODING_CP1252 = fontsc.wxFONTENCODING_CP1252
wxFONTENCODING_CP1253 = fontsc.wxFONTENCODING_CP1253
wxFONTENCODING_CP1254 = fontsc.wxFONTENCODING_CP1254
wxFONTENCODING_CP1255 = fontsc.wxFONTENCODING_CP1255
wxFONTENCODING_CP1256 = fontsc.wxFONTENCODING_CP1256
wxFONTENCODING_CP1257 = fontsc.wxFONTENCODING_CP1257
wxFONTENCODING_CP12_MAX = fontsc.wxFONTENCODING_CP12_MAX
wxFONTENCODING_UTF7 = fontsc.wxFONTENCODING_UTF7
wxFONTENCODING_UTF8 = fontsc.wxFONTENCODING_UTF8
wxFONTENCODING_GB2312 = fontsc.wxFONTENCODING_GB2312
wxFONTENCODING_BIG5 = fontsc.wxFONTENCODING_BIG5
wxFONTENCODING_SHIFT_JIS = fontsc.wxFONTENCODING_SHIFT_JIS
wxFONTENCODING_EUC_JP = fontsc.wxFONTENCODING_EUC_JP
wxFONTENCODING_UNICODE = fontsc.wxFONTENCODING_UNICODE
wxFONTENCODING_MAX = fontsc.wxFONTENCODING_MAX
wxLANGUAGE_DEFAULT = fontsc.wxLANGUAGE_DEFAULT
wxLANGUAGE_UNKNOWN = fontsc.wxLANGUAGE_UNKNOWN
wxLANGUAGE_ABKHAZIAN = fontsc.wxLANGUAGE_ABKHAZIAN
wxLANGUAGE_AFAR = fontsc.wxLANGUAGE_AFAR
wxLANGUAGE_AFRIKAANS = fontsc.wxLANGUAGE_AFRIKAANS
wxLANGUAGE_ALBANIAN = fontsc.wxLANGUAGE_ALBANIAN
wxLANGUAGE_AMHARIC = fontsc.wxLANGUAGE_AMHARIC
wxLANGUAGE_ARABIC = fontsc.wxLANGUAGE_ARABIC
wxLANGUAGE_ARABIC_ALGERIA = fontsc.wxLANGUAGE_ARABIC_ALGERIA
wxLANGUAGE_ARABIC_BAHRAIN = fontsc.wxLANGUAGE_ARABIC_BAHRAIN
wxLANGUAGE_ARABIC_EGYPT = fontsc.wxLANGUAGE_ARABIC_EGYPT
wxLANGUAGE_ARABIC_IRAQ = fontsc.wxLANGUAGE_ARABIC_IRAQ
wxLANGUAGE_ARABIC_JORDAN = fontsc.wxLANGUAGE_ARABIC_JORDAN
wxLANGUAGE_ARABIC_KUWAIT = fontsc.wxLANGUAGE_ARABIC_KUWAIT
wxLANGUAGE_ARABIC_LEBANON = fontsc.wxLANGUAGE_ARABIC_LEBANON
wxLANGUAGE_ARABIC_LIBYA = fontsc.wxLANGUAGE_ARABIC_LIBYA
wxLANGUAGE_ARABIC_MOROCCO = fontsc.wxLANGUAGE_ARABIC_MOROCCO
wxLANGUAGE_ARABIC_OMAN = fontsc.wxLANGUAGE_ARABIC_OMAN
wxLANGUAGE_ARABIC_QATAR = fontsc.wxLANGUAGE_ARABIC_QATAR
wxLANGUAGE_ARABIC_SAUDI_ARABIA = fontsc.wxLANGUAGE_ARABIC_SAUDI_ARABIA
wxLANGUAGE_ARABIC_SUDAN = fontsc.wxLANGUAGE_ARABIC_SUDAN
wxLANGUAGE_ARABIC_SYRIA = fontsc.wxLANGUAGE_ARABIC_SYRIA
wxLANGUAGE_ARABIC_TUNISIA = fontsc.wxLANGUAGE_ARABIC_TUNISIA
wxLANGUAGE_ARABIC_UAE = fontsc.wxLANGUAGE_ARABIC_UAE
wxLANGUAGE_ARABIC_YEMEN = fontsc.wxLANGUAGE_ARABIC_YEMEN
wxLANGUAGE_ARMENIAN = fontsc.wxLANGUAGE_ARMENIAN
wxLANGUAGE_ASSAMESE = fontsc.wxLANGUAGE_ASSAMESE
wxLANGUAGE_AYMARA = fontsc.wxLANGUAGE_AYMARA
wxLANGUAGE_AZERI = fontsc.wxLANGUAGE_AZERI
wxLANGUAGE_AZERI_CYRILLIC = fontsc.wxLANGUAGE_AZERI_CYRILLIC
wxLANGUAGE_AZERI_LATIN = fontsc.wxLANGUAGE_AZERI_LATIN
wxLANGUAGE_BASHKIR = fontsc.wxLANGUAGE_BASHKIR
wxLANGUAGE_BASQUE = fontsc.wxLANGUAGE_BASQUE
wxLANGUAGE_BELARUSIAN = fontsc.wxLANGUAGE_BELARUSIAN
wxLANGUAGE_BENGALI = fontsc.wxLANGUAGE_BENGALI
wxLANGUAGE_BHUTANI = fontsc.wxLANGUAGE_BHUTANI
wxLANGUAGE_BIHARI = fontsc.wxLANGUAGE_BIHARI
wxLANGUAGE_BISLAMA = fontsc.wxLANGUAGE_BISLAMA
wxLANGUAGE_BRETON = fontsc.wxLANGUAGE_BRETON
wxLANGUAGE_BULGARIAN = fontsc.wxLANGUAGE_BULGARIAN
wxLANGUAGE_BURMESE = fontsc.wxLANGUAGE_BURMESE
wxLANGUAGE_CAMBODIAN = fontsc.wxLANGUAGE_CAMBODIAN
wxLANGUAGE_CATALAN = fontsc.wxLANGUAGE_CATALAN
wxLANGUAGE_CHINESE = fontsc.wxLANGUAGE_CHINESE
wxLANGUAGE_CHINESE_SIMPLIFIED = fontsc.wxLANGUAGE_CHINESE_SIMPLIFIED
wxLANGUAGE_CHINESE_TRADITIONAL = fontsc.wxLANGUAGE_CHINESE_TRADITIONAL
wxLANGUAGE_CHINESE_HONGKONG = fontsc.wxLANGUAGE_CHINESE_HONGKONG
wxLANGUAGE_CHINESE_MACAU = fontsc.wxLANGUAGE_CHINESE_MACAU
wxLANGUAGE_CHINESE_SINGAPORE = fontsc.wxLANGUAGE_CHINESE_SINGAPORE
wxLANGUAGE_CHINESE_TAIWAN = fontsc.wxLANGUAGE_CHINESE_TAIWAN
wxLANGUAGE_CORSICAN = fontsc.wxLANGUAGE_CORSICAN
wxLANGUAGE_CROATIAN = fontsc.wxLANGUAGE_CROATIAN
wxLANGUAGE_CZECH = fontsc.wxLANGUAGE_CZECH
wxLANGUAGE_DANISH = fontsc.wxLANGUAGE_DANISH
wxLANGUAGE_DUTCH = fontsc.wxLANGUAGE_DUTCH
wxLANGUAGE_DUTCH_BELGIAN = fontsc.wxLANGUAGE_DUTCH_BELGIAN
wxLANGUAGE_ENGLISH = fontsc.wxLANGUAGE_ENGLISH
wxLANGUAGE_ENGLISH_UK = fontsc.wxLANGUAGE_ENGLISH_UK
wxLANGUAGE_ENGLISH_US = fontsc.wxLANGUAGE_ENGLISH_US
wxLANGUAGE_ENGLISH_AUSTRALIA = fontsc.wxLANGUAGE_ENGLISH_AUSTRALIA
wxLANGUAGE_ENGLISH_BELIZE = fontsc.wxLANGUAGE_ENGLISH_BELIZE
wxLANGUAGE_ENGLISH_BOTSWANA = fontsc.wxLANGUAGE_ENGLISH_BOTSWANA
wxLANGUAGE_ENGLISH_CANADA = fontsc.wxLANGUAGE_ENGLISH_CANADA
wxLANGUAGE_ENGLISH_CARIBBEAN = fontsc.wxLANGUAGE_ENGLISH_CARIBBEAN
wxLANGUAGE_ENGLISH_DENMARK = fontsc.wxLANGUAGE_ENGLISH_DENMARK
wxLANGUAGE_ENGLISH_EIRE = fontsc.wxLANGUAGE_ENGLISH_EIRE
wxLANGUAGE_ENGLISH_JAMAICA = fontsc.wxLANGUAGE_ENGLISH_JAMAICA
wxLANGUAGE_ENGLISH_NEW_ZEALAND = fontsc.wxLANGUAGE_ENGLISH_NEW_ZEALAND
wxLANGUAGE_ENGLISH_PHILIPPINES = fontsc.wxLANGUAGE_ENGLISH_PHILIPPINES
wxLANGUAGE_ENGLISH_SOUTH_AFRICA = fontsc.wxLANGUAGE_ENGLISH_SOUTH_AFRICA
wxLANGUAGE_ENGLISH_TRINIDAD = fontsc.wxLANGUAGE_ENGLISH_TRINIDAD
wxLANGUAGE_ENGLISH_ZIMBABWE = fontsc.wxLANGUAGE_ENGLISH_ZIMBABWE
wxLANGUAGE_ESPERANTO = fontsc.wxLANGUAGE_ESPERANTO
wxLANGUAGE_ESTONIAN = fontsc.wxLANGUAGE_ESTONIAN
wxLANGUAGE_FAEROESE = fontsc.wxLANGUAGE_FAEROESE
wxLANGUAGE_FARSI = fontsc.wxLANGUAGE_FARSI
wxLANGUAGE_FIJI = fontsc.wxLANGUAGE_FIJI
wxLANGUAGE_FINNISH = fontsc.wxLANGUAGE_FINNISH
wxLANGUAGE_FRENCH = fontsc.wxLANGUAGE_FRENCH
wxLANGUAGE_FRENCH_BELGIAN = fontsc.wxLANGUAGE_FRENCH_BELGIAN
wxLANGUAGE_FRENCH_CANADIAN = fontsc.wxLANGUAGE_FRENCH_CANADIAN
wxLANGUAGE_FRENCH_LUXEMBOURG = fontsc.wxLANGUAGE_FRENCH_LUXEMBOURG
wxLANGUAGE_FRENCH_MONACO = fontsc.wxLANGUAGE_FRENCH_MONACO
wxLANGUAGE_FRENCH_SWISS = fontsc.wxLANGUAGE_FRENCH_SWISS
wxLANGUAGE_FRISIAN = fontsc.wxLANGUAGE_FRISIAN
wxLANGUAGE_GALICIAN = fontsc.wxLANGUAGE_GALICIAN
wxLANGUAGE_GEORGIAN = fontsc.wxLANGUAGE_GEORGIAN
wxLANGUAGE_GERMAN = fontsc.wxLANGUAGE_GERMAN
wxLANGUAGE_GERMAN_AUSTRIAN = fontsc.wxLANGUAGE_GERMAN_AUSTRIAN
wxLANGUAGE_GERMAN_BELGIUM = fontsc.wxLANGUAGE_GERMAN_BELGIUM
wxLANGUAGE_GERMAN_LIECHTENSTEIN = fontsc.wxLANGUAGE_GERMAN_LIECHTENSTEIN
wxLANGUAGE_GERMAN_LUXEMBOURG = fontsc.wxLANGUAGE_GERMAN_LUXEMBOURG
wxLANGUAGE_GERMAN_SWISS = fontsc.wxLANGUAGE_GERMAN_SWISS
wxLANGUAGE_GREEK = fontsc.wxLANGUAGE_GREEK
wxLANGUAGE_GREENLANDIC = fontsc.wxLANGUAGE_GREENLANDIC
wxLANGUAGE_GUARANI = fontsc.wxLANGUAGE_GUARANI
wxLANGUAGE_GUJARATI = fontsc.wxLANGUAGE_GUJARATI
wxLANGUAGE_HAUSA = fontsc.wxLANGUAGE_HAUSA
wxLANGUAGE_HEBREW = fontsc.wxLANGUAGE_HEBREW
wxLANGUAGE_HINDI = fontsc.wxLANGUAGE_HINDI
wxLANGUAGE_HUNGARIAN = fontsc.wxLANGUAGE_HUNGARIAN
wxLANGUAGE_ICELANDIC = fontsc.wxLANGUAGE_ICELANDIC
wxLANGUAGE_INDONESIAN = fontsc.wxLANGUAGE_INDONESIAN
wxLANGUAGE_INTERLINGUA = fontsc.wxLANGUAGE_INTERLINGUA
wxLANGUAGE_INTERLINGUE = fontsc.wxLANGUAGE_INTERLINGUE
wxLANGUAGE_INUKTITUT = fontsc.wxLANGUAGE_INUKTITUT
wxLANGUAGE_INUPIAK = fontsc.wxLANGUAGE_INUPIAK
wxLANGUAGE_IRISH = fontsc.wxLANGUAGE_IRISH
wxLANGUAGE_ITALIAN = fontsc.wxLANGUAGE_ITALIAN
wxLANGUAGE_ITALIAN_SWISS = fontsc.wxLANGUAGE_ITALIAN_SWISS
wxLANGUAGE_JAPANESE = fontsc.wxLANGUAGE_JAPANESE
wxLANGUAGE_JAVANESE = fontsc.wxLANGUAGE_JAVANESE
wxLANGUAGE_KANNADA = fontsc.wxLANGUAGE_KANNADA
wxLANGUAGE_KASHMIRI = fontsc.wxLANGUAGE_KASHMIRI
wxLANGUAGE_KASHMIRI_INDIA = fontsc.wxLANGUAGE_KASHMIRI_INDIA
wxLANGUAGE_KAZAKH = fontsc.wxLANGUAGE_KAZAKH
wxLANGUAGE_KERNEWEK = fontsc.wxLANGUAGE_KERNEWEK
wxLANGUAGE_KINYARWANDA = fontsc.wxLANGUAGE_KINYARWANDA
wxLANGUAGE_KIRGHIZ = fontsc.wxLANGUAGE_KIRGHIZ
wxLANGUAGE_KIRUNDI = fontsc.wxLANGUAGE_KIRUNDI
wxLANGUAGE_KONKANI = fontsc.wxLANGUAGE_KONKANI
wxLANGUAGE_KOREAN = fontsc.wxLANGUAGE_KOREAN
wxLANGUAGE_KURDISH = fontsc.wxLANGUAGE_KURDISH
wxLANGUAGE_LAOTHIAN = fontsc.wxLANGUAGE_LAOTHIAN
wxLANGUAGE_LATIN = fontsc.wxLANGUAGE_LATIN
wxLANGUAGE_LATVIAN = fontsc.wxLANGUAGE_LATVIAN
wxLANGUAGE_LINGALA = fontsc.wxLANGUAGE_LINGALA
wxLANGUAGE_LITHUANIAN = fontsc.wxLANGUAGE_LITHUANIAN
wxLANGUAGE_MACEDONIAN = fontsc.wxLANGUAGE_MACEDONIAN
wxLANGUAGE_MALAGASY = fontsc.wxLANGUAGE_MALAGASY
wxLANGUAGE_MALAY = fontsc.wxLANGUAGE_MALAY
wxLANGUAGE_MALAYALAM = fontsc.wxLANGUAGE_MALAYALAM
wxLANGUAGE_MALAY_BRUNEI_DARUSSALAM = fontsc.wxLANGUAGE_MALAY_BRUNEI_DARUSSALAM
wxLANGUAGE_MALAY_MALAYSIA = fontsc.wxLANGUAGE_MALAY_MALAYSIA
wxLANGUAGE_MALTESE = fontsc.wxLANGUAGE_MALTESE
wxLANGUAGE_MANIPURI = fontsc.wxLANGUAGE_MANIPURI
wxLANGUAGE_MAORI = fontsc.wxLANGUAGE_MAORI
wxLANGUAGE_MARATHI = fontsc.wxLANGUAGE_MARATHI
wxLANGUAGE_MOLDAVIAN = fontsc.wxLANGUAGE_MOLDAVIAN
wxLANGUAGE_MONGOLIAN = fontsc.wxLANGUAGE_MONGOLIAN
wxLANGUAGE_NAURU = fontsc.wxLANGUAGE_NAURU
wxLANGUAGE_NEPALI = fontsc.wxLANGUAGE_NEPALI
wxLANGUAGE_NEPALI_INDIA = fontsc.wxLANGUAGE_NEPALI_INDIA
wxLANGUAGE_NORWEGIAN_BOKMAL = fontsc.wxLANGUAGE_NORWEGIAN_BOKMAL
wxLANGUAGE_NORWEGIAN_NYNORSK = fontsc.wxLANGUAGE_NORWEGIAN_NYNORSK
wxLANGUAGE_OCCITAN = fontsc.wxLANGUAGE_OCCITAN
wxLANGUAGE_ORIYA = fontsc.wxLANGUAGE_ORIYA
wxLANGUAGE_OROMO = fontsc.wxLANGUAGE_OROMO
wxLANGUAGE_PASHTO = fontsc.wxLANGUAGE_PASHTO
wxLANGUAGE_POLISH = fontsc.wxLANGUAGE_POLISH
wxLANGUAGE_PORTUGUESE = fontsc.wxLANGUAGE_PORTUGUESE
wxLANGUAGE_PORTUGUESE_BRAZILIAN = fontsc.wxLANGUAGE_PORTUGUESE_BRAZILIAN
wxLANGUAGE_PUNJABI = fontsc.wxLANGUAGE_PUNJABI
wxLANGUAGE_QUECHUA = fontsc.wxLANGUAGE_QUECHUA
wxLANGUAGE_RHAETO_ROMANCE = fontsc.wxLANGUAGE_RHAETO_ROMANCE
wxLANGUAGE_ROMANIAN = fontsc.wxLANGUAGE_ROMANIAN
wxLANGUAGE_RUSSIAN = fontsc.wxLANGUAGE_RUSSIAN
wxLANGUAGE_RUSSIAN_UKRAINE = fontsc.wxLANGUAGE_RUSSIAN_UKRAINE
wxLANGUAGE_SAMOAN = fontsc.wxLANGUAGE_SAMOAN
wxLANGUAGE_SANGHO = fontsc.wxLANGUAGE_SANGHO
wxLANGUAGE_SANSKRIT = fontsc.wxLANGUAGE_SANSKRIT
wxLANGUAGE_SCOTS_GAELIC = fontsc.wxLANGUAGE_SCOTS_GAELIC
wxLANGUAGE_SERBIAN = fontsc.wxLANGUAGE_SERBIAN
wxLANGUAGE_SERBIAN_CYRILLIC = fontsc.wxLANGUAGE_SERBIAN_CYRILLIC
wxLANGUAGE_SERBIAN_LATIN = fontsc.wxLANGUAGE_SERBIAN_LATIN
wxLANGUAGE_SERBO_CROATIAN = fontsc.wxLANGUAGE_SERBO_CROATIAN
wxLANGUAGE_SESOTHO = fontsc.wxLANGUAGE_SESOTHO
wxLANGUAGE_SETSWANA = fontsc.wxLANGUAGE_SETSWANA
wxLANGUAGE_SHONA = fontsc.wxLANGUAGE_SHONA
wxLANGUAGE_SINDHI = fontsc.wxLANGUAGE_SINDHI
wxLANGUAGE_SINHALESE = fontsc.wxLANGUAGE_SINHALESE
wxLANGUAGE_SISWATI = fontsc.wxLANGUAGE_SISWATI
wxLANGUAGE_SLOVAK = fontsc.wxLANGUAGE_SLOVAK
wxLANGUAGE_SLOVENIAN = fontsc.wxLANGUAGE_SLOVENIAN
wxLANGUAGE_SOMALI = fontsc.wxLANGUAGE_SOMALI
wxLANGUAGE_SPANISH = fontsc.wxLANGUAGE_SPANISH
wxLANGUAGE_SPANISH_ARGENTINA = fontsc.wxLANGUAGE_SPANISH_ARGENTINA
wxLANGUAGE_SPANISH_BOLIVIA = fontsc.wxLANGUAGE_SPANISH_BOLIVIA
wxLANGUAGE_SPANISH_CHILE = fontsc.wxLANGUAGE_SPANISH_CHILE
wxLANGUAGE_SPANISH_COLOMBIA = fontsc.wxLANGUAGE_SPANISH_COLOMBIA
wxLANGUAGE_SPANISH_COSTA_RICA = fontsc.wxLANGUAGE_SPANISH_COSTA_RICA
wxLANGUAGE_SPANISH_DOMINICAN_REPUBLIC = fontsc.wxLANGUAGE_SPANISH_DOMINICAN_REPUBLIC
wxLANGUAGE_SPANISH_ECUADOR = fontsc.wxLANGUAGE_SPANISH_ECUADOR
wxLANGUAGE_SPANISH_EL_SALVADOR = fontsc.wxLANGUAGE_SPANISH_EL_SALVADOR
wxLANGUAGE_SPANISH_GUATEMALA = fontsc.wxLANGUAGE_SPANISH_GUATEMALA
wxLANGUAGE_SPANISH_HONDURAS = fontsc.wxLANGUAGE_SPANISH_HONDURAS
wxLANGUAGE_SPANISH_MEXICAN = fontsc.wxLANGUAGE_SPANISH_MEXICAN
wxLANGUAGE_SPANISH_MODERN = fontsc.wxLANGUAGE_SPANISH_MODERN
wxLANGUAGE_SPANISH_NICARAGUA = fontsc.wxLANGUAGE_SPANISH_NICARAGUA
wxLANGUAGE_SPANISH_PANAMA = fontsc.wxLANGUAGE_SPANISH_PANAMA
wxLANGUAGE_SPANISH_PARAGUAY = fontsc.wxLANGUAGE_SPANISH_PARAGUAY
wxLANGUAGE_SPANISH_PERU = fontsc.wxLANGUAGE_SPANISH_PERU
wxLANGUAGE_SPANISH_PUERTO_RICO = fontsc.wxLANGUAGE_SPANISH_PUERTO_RICO
wxLANGUAGE_SPANISH_URUGUAY = fontsc.wxLANGUAGE_SPANISH_URUGUAY
wxLANGUAGE_SPANISH_US = fontsc.wxLANGUAGE_SPANISH_US
wxLANGUAGE_SPANISH_VENEZUELA = fontsc.wxLANGUAGE_SPANISH_VENEZUELA
wxLANGUAGE_SUNDANESE = fontsc.wxLANGUAGE_SUNDANESE
wxLANGUAGE_SWAHILI = fontsc.wxLANGUAGE_SWAHILI
wxLANGUAGE_SWEDISH = fontsc.wxLANGUAGE_SWEDISH
wxLANGUAGE_SWEDISH_FINLAND = fontsc.wxLANGUAGE_SWEDISH_FINLAND
wxLANGUAGE_TAGALOG = fontsc.wxLANGUAGE_TAGALOG
wxLANGUAGE_TAJIK = fontsc.wxLANGUAGE_TAJIK
wxLANGUAGE_TAMIL = fontsc.wxLANGUAGE_TAMIL
wxLANGUAGE_TATAR = fontsc.wxLANGUAGE_TATAR
wxLANGUAGE_TELUGU = fontsc.wxLANGUAGE_TELUGU
wxLANGUAGE_THAI = fontsc.wxLANGUAGE_THAI
wxLANGUAGE_TIBETAN = fontsc.wxLANGUAGE_TIBETAN
wxLANGUAGE_TIGRINYA = fontsc.wxLANGUAGE_TIGRINYA
wxLANGUAGE_TONGA = fontsc.wxLANGUAGE_TONGA
wxLANGUAGE_TSONGA = fontsc.wxLANGUAGE_TSONGA
wxLANGUAGE_TURKISH = fontsc.wxLANGUAGE_TURKISH
wxLANGUAGE_TURKMEN = fontsc.wxLANGUAGE_TURKMEN
wxLANGUAGE_TWI = fontsc.wxLANGUAGE_TWI
wxLANGUAGE_UIGHUR = fontsc.wxLANGUAGE_UIGHUR
wxLANGUAGE_UKRAINIAN = fontsc.wxLANGUAGE_UKRAINIAN
wxLANGUAGE_URDU = fontsc.wxLANGUAGE_URDU
wxLANGUAGE_URDU_INDIA = fontsc.wxLANGUAGE_URDU_INDIA
wxLANGUAGE_URDU_PAKISTAN = fontsc.wxLANGUAGE_URDU_PAKISTAN
wxLANGUAGE_UZBEK = fontsc.wxLANGUAGE_UZBEK
wxLANGUAGE_UZBEK_CYRILLIC = fontsc.wxLANGUAGE_UZBEK_CYRILLIC
wxLANGUAGE_UZBEK_LATIN = fontsc.wxLANGUAGE_UZBEK_LATIN
wxLANGUAGE_VIETNAMESE = fontsc.wxLANGUAGE_VIETNAMESE
wxLANGUAGE_VOLAPUK = fontsc.wxLANGUAGE_VOLAPUK
wxLANGUAGE_WELSH = fontsc.wxLANGUAGE_WELSH
wxLANGUAGE_WOLOF = fontsc.wxLANGUAGE_WOLOF
wxLANGUAGE_XHOSA = fontsc.wxLANGUAGE_XHOSA
wxLANGUAGE_YIDDISH = fontsc.wxLANGUAGE_YIDDISH
wxLANGUAGE_YORUBA = fontsc.wxLANGUAGE_YORUBA
wxLANGUAGE_ZHUANG = fontsc.wxLANGUAGE_ZHUANG
wxLANGUAGE_ZULU = fontsc.wxLANGUAGE_ZULU
wxLANGUAGE_USER_DEFINED = fontsc.wxLANGUAGE_USER_DEFINED
wxLOCALE_CAT_NUMBER = fontsc.wxLOCALE_CAT_NUMBER
wxLOCALE_CAT_DATE = fontsc.wxLOCALE_CAT_DATE
wxLOCALE_CAT_MONEY = fontsc.wxLOCALE_CAT_MONEY
wxLOCALE_CAT_MAX = fontsc.wxLOCALE_CAT_MAX
wxLOCALE_THOUSANDS_SEP = fontsc.wxLOCALE_THOUSANDS_SEP
wxLOCALE_DECIMAL_POINT = fontsc.wxLOCALE_DECIMAL_POINT
wxLOCALE_LOAD_DEFAULT = fontsc.wxLOCALE_LOAD_DEFAULT
wxLOCALE_CONV_ENCODING = fontsc.wxLOCALE_CONV_ENCODING
wxCONVERT_STRICT = fontsc.wxCONVERT_STRICT
wxCONVERT_SUBSTITUTE = fontsc.wxCONVERT_SUBSTITUTE
wxPLATFORM_CURRENT = fontsc.wxPLATFORM_CURRENT
wxPLATFORM_UNIX = fontsc.wxPLATFORM_UNIX
wxPLATFORM_WINDOWS = fontsc.wxPLATFORM_WINDOWS
wxPLATFORM_OS2 = fontsc.wxPLATFORM_OS2
wxPLATFORM_MAC = fontsc.wxPLATFORM_MAC



"""Decorator classes for documentation and shell scripting.
"""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: SashSplitter.py,v 1.1.2.1 2003/03/11 19:37:12 RD Exp $"
__revision__ = "$Revision: 1.1.2.1 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


import Parameters as wx
from Window import Window


class SashWindow(Window):
    """"""

    def Create(self):
        """"""
        pass

    def GetDefaultBorderSize(self):
        """"""
        pass

    def GetEdgeMargin(self):
        """"""
        pass

    def GetExtraBorderSize(self):
        """"""
        pass

    def GetMaximumSizeX(self):
        """"""
        pass

    def GetMaximumSizeY(self):
        """"""
        pass

    def GetMinimumSizeX(self):
        """"""
        pass

    def GetMinimumSizeY(self):
        """"""
        pass

    def GetSashVisible(self):
        """"""
        pass

    def HasBorder(self):
        """"""
        pass

    def SetDefaultBorderSize(self):
        """"""
        pass

    def SetExtraBorderSize(self):
        """"""
        pass

    def SetMaximumSizeX(self):
        """"""
        pass

    def SetMaximumSizeY(self):
        """"""
        pass

    def SetMinimumSizeX(self):
        """"""
        pass

    def SetMinimumSizeY(self):
        """"""
        pass

    def SetSashBorder(self):
        """"""
        pass

    def SetSashVisible(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class SashLayoutWindow(SashWindow):
    """"""

    def Create(self):
        """"""
        pass

    def GetAlignment(self):
        """"""
        pass

    def GetOrientation(self):
        """"""
        pass

    def SetAlignment(self):
        """"""
        pass

    def SetDefaultSize(self):
        """"""
        pass

    def SetOrientation(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class SplitterWindow(Window):
    """"""

    def Create(self):
        """"""
        pass

    def GetBorderSize(self):
        """"""
        pass

    def GetMinimumPaneSize(self):
        """"""
        pass

    def GetNeedUpdating(self):
        """"""
        pass

    def GetSashPosition(self):
        """"""
        pass

    def GetSashSize(self):
        """"""
        pass

    def GetSplitMode(self):
        """"""
        pass

    def GetWindow1(self):
        """"""
        pass

    def GetWindow2(self):
        """"""
        pass

    def Initialize(self):
        """"""
        pass

    def IsSplit(self):
        """"""
        pass

    def ReplaceWindow(self):
        """"""
        pass

    def SetBorderSize(self):
        """"""
        pass

    def SetMinimumPaneSize(self):
        """"""
        pass

    def SetNeedUpdating(self):
        """"""
        pass

    def SetSashPosition(self):
        """"""
        pass

    def SetSashSize(self):
        """"""
        pass

    def SetSplitMode(self):
        """"""
        pass

    def SizeWindows(self):
        """"""
        pass

    def SplitHorizontally(self):
        """"""
        pass

    def SplitVertically(self):
        """"""
        pass

    def Unsplit(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass





"""
wxPyColourChooser
Copyright (C) 2002 Michael Gilfix <mgilfix@eecs.tufts.edu>

This file is part of wxPyColourChooser.

This version of wxPyColourChooser is open source; you can redistribute it
and/or modify it under the licensed terms.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
"""

import pycolourbox
import pypalette
import pycolourslider
import colorsys
from intl import _
from wxPython.wx import *

class wxPyColourChooser(wxPanel):
    """A Pure-Python implementation of the colour chooser dialog.

    The PyColourChooser is a pure python implementation of the colour
    chooser dialog. It's useful for embedding the colour choosing functionality
    inside other widgets, when the pop-up dialog is undesirable. It can also
    be used as a drop-in replacement on the GTK platform, as the native
    dialog is kind of ugly.
    """

    colour_names = [
        'ORANGE',
        'GOLDENROD',
        'WHEAT',
        'SPRING GREEN',
        'SKY BLUE',
        'SLATE BLUE',
        'MEDIUM VIOLET RED',
        'PURPLE',

        'RED',
        'YELLOW',
        'MEDIUM SPRING GREEN',
        'PALE GREEN',
        'CYAN',
        'LIGHT STEEL BLUE',
        'ORCHID',
        'LIGHT MAGENTA',

        'BROWN',
        'YELLOW',
        'GREEN',
        'CADET BLUE',
        'MEDIUM BLUE',
        'MAGENTA',
        'MAROON',
        'ORANGE RED',

        'FIREBRICK',
        'CORAL',
        'FOREST GREEN',
        'AQUAMARINE',
        'BLUE',
        'NAVY',
        'THISTLE',
        'MEDIUM VIOLET RED',

        'INDIAN RED',
        'GOLD',
        'MEDIUM SEA GREEN',
        'MEDIUM BLUE',
        'MIDNIGHT BLUE',
        'GREY',
        'PURPLE',
        'KHAKI',

        'BLACK',
        'MEDIUM FOREST GREEN',
        'KHAKI',
        'DARK GREY',
        'SEA GREEN',
        'LIGHT GREY',
        'MEDIUM SLATE BLUE',
        'WHITE',
    ]

    # Generate the custom colours. These colours are shared across
    # all instances of the colour chooser
    NO_CUSTOM_COLOURS = 16
    custom_colours = [ (wxColour(255, 255, 255),
                        pycolourslider.PyColourSlider.HEIGHT / 2)
                     ] * NO_CUSTOM_COLOURS
    last_custom = 0

    idADD_CUSTOM = wxNewId()
    idSCROLL     = wxNewId()

    def __init__(self, parent, id):
        """Creates an instance of the colour chooser. Note that it is best to
        accept the given size of the colour chooser as it is currently not
        resizeable."""
        wxPanel.__init__(self, parent, id)

        self.basic_label = wxStaticText(self, -1, _("Basic Colours:"))
        self.custom_label = wxStaticText(self, -1, _("Custom Colours:"))
        self.add_button = wxButton(self, self.idADD_CUSTOM, _("Add to Custom Colours"))

        EVT_BUTTON(self, self.idADD_CUSTOM, self.onAddCustom)

        # Since we're going to be constructing widgets that require some serious
        # computation, let's process any events (like redraws) right now
        wxYield()

        # Create the basic colours palette
        self.colour_boxs = [ ]
        colour_grid = wxGridSizer(6, 8)
        for name in self.colour_names:
            new_id = wxNewId()
            box = pycolourbox.PyColourBox(self, new_id)
            EVT_LEFT_DOWN(box.GetColourBox(), lambda x, b=box: self.onBasicClick(x, b))
            self.colour_boxs.append(box)
            colour_grid.Add(box, 0, wxEXPAND)

        # Create the custom colours palette
        self.custom_boxs = [ ]
        custom_grid = wxGridSizer(2, 8)
        for wxcolour, slidepos in self.custom_colours:
            new_id = wxNewId()
            custom = pycolourbox.PyColourBox(self, new_id)
            EVT_LEFT_DOWN(custom.GetColourBox(), lambda x, b=custom: self.onCustomClick(x, b))
            custom.SetColour(wxcolour)
            custom_grid.Add(custom, 0, wxEXPAND)
            self.custom_boxs.append(custom)

        csizer = wxBoxSizer(wxVERTICAL)
        csizer.Add(1, 25)
        csizer.Add(self.basic_label, 0, wxEXPAND)
        csizer.Add(1, 5)
        csizer.Add(colour_grid, 0, wxEXPAND)
        csizer.Add(1, 25)
        csizer.Add(self.custom_label, 0, wxEXPAND)
        csizer.Add(1, 5)
        csizer.Add(custom_grid, 0, wxEXPAND)
        csizer.Add(1, 5)
        csizer.Add(self.add_button, 0, wxEXPAND)

        self.palette = pypalette.PyPalette(self, -1)
        self.colour_slider = pycolourslider.PyColourSlider(self, -1)
        self.slider = wxSlider(self, self.idSCROLL, 86, 0, self.colour_slider.HEIGHT - 1,
                                style=wxSL_VERTICAL, size=wxSize(15, self.colour_slider.HEIGHT))
        EVT_COMMAND_SCROLL(self, self.idSCROLL, self.onScroll)
        psizer = wxBoxSizer(wxHORIZONTAL)
        psizer.Add(self.palette, 0, 0)
        psizer.Add(10, 1)
        psizer.Add(self.colour_slider, 0, wxALIGN_CENTER_VERTICAL)
        psizer.Add(self.slider, 0, wxALIGN_CENTER_VERTICAL)

        # Register mouse events for dragging across the palette
        EVT_LEFT_DOWN(self.palette, self.onPaletteDown)
        EVT_LEFT_UP(self.palette, self.onPaletteUp)
        EVT_MOTION(self.palette, self.onPaletteMotion)
        self.mouse_down = False

        self.solid = pycolourbox.PyColourBox(self, -1, size=wxSize(75, 50))
        slabel = wxStaticText(self, -1, _("Solid Colour"))
        ssizer = wxBoxSizer(wxVERTICAL)
        ssizer.Add(self.solid, 0, 0)
        ssizer.Add(1, 2)
        ssizer.Add(slabel, 0, wxALIGN_CENTER_HORIZONTAL)

        hlabel = wxStaticText(self, -1, _("H:"))
        self.hentry = wxTextCtrl(self, -1)
        self.hentry.SetSize((40, -1))
        slabel = wxStaticText(self, -1, _("S:"))
        self.sentry = wxTextCtrl(self, -1)
        self.sentry.SetSize((40, -1))
        vlabel = wxStaticText(self, -1, _("V:"))
        self.ventry = wxTextCtrl(self, -1)
        self.ventry.SetSize((40, -1))
        hsvgrid = wxFlexGridSizer(1, 6, 2, 2)
        hsvgrid.AddMany ([
            (hlabel, 0, wxALIGN_CENTER_VERTICAL), (self.hentry, 0, 0),
            (slabel, 0, wxALIGN_CENTER_VERTICAL), (self.sentry, 0, 0),
            (vlabel, 0, wxALIGN_CENTER_VERTICAL), (self.ventry, 0, 0),
        ])

        rlabel = wxStaticText(self, -1, _("R:"))
        self.rentry = wxTextCtrl(self, -1)
        self.rentry.SetSize((40, -1))
        glabel = wxStaticText(self, -1, _("G:"))
        self.gentry = wxTextCtrl(self, -1)
        self.gentry.SetSize((40, -1))
        blabel = wxStaticText(self, -1, _("B:"))
        self.bentry = wxTextCtrl(self, -1)
        self.bentry.SetSize((40, -1))
        lgrid = wxFlexGridSizer(1, 6, 2, 2)
        lgrid.AddMany([
            (rlabel, 0, wxALIGN_CENTER_VERTICAL), (self.rentry, 0, 0),
            (glabel, 0, wxALIGN_CENTER_VERTICAL), (self.gentry, 0, 0),
            (blabel, 0, wxALIGN_CENTER_VERTICAL), (self.bentry, 0, 0),
        ])

        gsizer = wxGridSizer(2, 1)
        gsizer.SetVGap (10)
        gsizer.SetHGap (2)
        gsizer.Add(hsvgrid, 0, wxALIGN_CENTER_VERTICAL | wxALIGN_CENTER_HORIZONTAL)
        gsizer.Add(lgrid, 0, wxALIGN_CENTER_VERTICAL | wxALIGN_CENTER_HORIZONTAL)

        hsizer = wxBoxSizer(wxHORIZONTAL)
        hsizer.Add(ssizer, 0, wxALIGN_CENTER_VERTICAL | wxALIGN_CENTER_HORIZONTAL)
        hsizer.Add(gsizer, 0, wxALIGN_CENTER_VERTICAL | wxALIGN_CENTER_HORIZONTAL)

        vsizer = wxBoxSizer(wxVERTICAL)
        vsizer.Add(1, 5)
        vsizer.Add(psizer, 0, 0)
        vsizer.Add(1, 15)
        vsizer.Add(hsizer, 0, wxEXPAND)

        sizer = wxBoxSizer(wxHORIZONTAL)
        sizer.Add(5, 1)
        sizer.Add(csizer, 0, wxEXPAND)
        sizer.Add(10, 1)
        sizer.Add(vsizer, 0, wxEXPAND)
        self.SetAutoLayout(True)
        self.SetSizer(sizer)
        sizer.Fit(self)

        self.InitColours()
        self.UpdateColour(self.solid.GetColour())

    def InitColours(self):
        """Initializes the pre-set palette colours."""
        for i in range(len(self.colour_names)):
            colour = wxTheColourDatabase.FindColour(self.colour_names[i])
            self.colour_boxs[i].SetColourTuple((colour.Red(),
                                                colour.Green(),
                                                colour.Blue()))

    def onBasicClick(self, event, box):
        """Highlights the selected colour box and updates the solid colour
        display and colour slider to reflect the choice."""
        if hasattr(self, '_old_custom_highlight'):
            self._old_custom_highlight.SetHighlight(False)
        if hasattr(self, '_old_colour_highlight'):
            self._old_colour_highlight.SetHighlight(False)
        box.SetHighlight(True)
        self._old_colour_highlight = box
        self.UpdateColour(box.GetColour())

    def onCustomClick(self, event, box):
        """Highlights the selected custom colour box and updates the solid
        colour display and colour slider to reflect the choice."""
        if hasattr(self, '_old_colour_highlight'):
            self._old_colour_highlight.SetHighlight(False)
        if hasattr(self, '_old_custom_highlight'):
            self._old_custom_highlight.SetHighlight(False)
        box.SetHighlight(True)
        self._old_custom_highlight = box

        # Update the colour panel and then the slider accordingly
        box_index = self.custom_boxs.index(box)
        base_colour, slidepos = self.custom_colours[box_index]
        self.UpdateColour(box.GetColour())
        self.slider.SetValue(slidepos)

    def onAddCustom(self, event):
        """Adds a custom colour to the custom colour box set. Boxes are
        chosen in a round-robin fashion, eventually overwriting previously
        added colours."""
        # Store the colour and slider position so we can restore the
        # custom colours just as they were
        self.setCustomColour(self.last_custom,
                             self.solid.GetColour(),
                             self.colour_slider.GetBaseColour(),
                             self.slider.GetValue())
        self.last_custom = (self.last_custom + 1) % self.NO_CUSTOM_COLOURS

    def setCustomColour (self, index, true_colour, base_colour, slidepos):
        """Sets the custom colour at the given index. true_colour is wxColour
        object containing the actual rgb value of the custom colour.
        base_colour (wxColour) and slidepos (int) are used to configure the
        colour slider and set everything to its original position."""
        self.custom_boxs[index].SetColour(true_colour)
        self.custom_colours[index] = (base_colour, slidepos)

    def UpdateColour(self, colour):
        """Performs necessary updates for when the colour selection has
        changed."""
        # Reset the palette to erase any highlighting
        self.palette.ReDraw()

        # Set the color info
        self.solid.SetColour(colour)
        self.colour_slider.SetBaseColour(colour)
        self.colour_slider.ReDraw()
        self.slider.SetValue(0)
        self.UpdateEntries(colour)

    def UpdateEntries(self, colour):
        """Updates the color levels to display the new values."""
        # Temporary bindings
        r = colour.Red()
        g = colour.Green()
        b = colour.Blue()

        # Update the RGB entries
        self.rentry.SetValue(str(r))
        self.gentry.SetValue(str(g))
        self.bentry.SetValue(str(b))

        # Convert to HSV
        h,s,v = colorsys.rgb_to_hsv(r / 255.0, g / 255.0, b / 255.0)
        self.hentry.SetValue("%.2f" % (h))
        self.sentry.SetValue("%.2f" % (s))
        self.ventry.SetValue("%.2f" % (v))

    def onPaletteDown(self, event):
        """Stores state that the mouse has been pressed and updates
        the selected colour values."""
        self.mouse_down = True
        self.palette.ReDraw()
        self.doPaletteClick(event.m_x, event.m_y)

    def onPaletteUp(self, event):
        """Stores state that the mouse is no longer depressed."""
        self.mouse_down = False

    def onPaletteMotion(self, event):
        """Updates the colour values during mouse motion while the
        mouse button is depressed."""
        if self.mouse_down:
            self.doPaletteClick(event.m_x, event.m_y)

    def doPaletteClick(self, m_x, m_y):
        """Updates the colour values based on the mouse location
        over the palette."""
        # Get the colour value and update
        colour = self.palette.GetValue(m_x, m_y)
        self.UpdateColour(colour)

        # Highlight a fresh selected area
        self.palette.ReDraw()
        self.palette.HighlightPoint(m_x, m_y)

        # Force an onscreen update
        self.solid.Update()
        self.colour_slider.Refresh()

    def onScroll(self, event):
        """Updates the solid colour display to reflect the changing slider."""
        value = self.slider.GetValue()
        colour = self.colour_slider.GetValue(value)
        self.solid.SetColour(colour)
        self.UpdateEntries(colour)

    def SetValue(self, colour):
        """Updates the colour chooser to reflect the given wxColour."""
        self.UpdateColour(colour)

    def GetValue(self):
        """Returns a wxColour object indicating the current colour choice."""
        return self.solid.GetColour()

def main():
    """Simple test display."""
    class App(wxApp):
        def OnInit(self):
            frame = wxFrame(NULL, -1, 'PyColourChooser Test')

            chooser = wxPyColourChooser(frame, -1)
            sizer = wxBoxSizer(wxVERTICAL)
            sizer.Add(chooser, 0, 0)
            frame.SetAutoLayout(True)
            frame.SetSizer(sizer)
            sizer.Fit(frame)

            frame.Show(True)
            self.SetTopWindow(frame)
            return True
    app = App()
    app.MainLoop()

if __name__ == '__main__':
    main()



"""
A throbber displays an animated image that can be
started, stopped, reversed, etc.  Useful for showing
an ongoing process (like most web browsers use) or
simply for adding eye-candy to an application.

Throbbers run in a separate thread so normal application
processing can continue unencumbered.
"""

#
# throbber.py - Cliff Wells <clifford.wells@attbi.com>
#
# Thanks to Harald Massa <harald.massa@suedvers.de> for
# suggestions and sample code.
#
# $Id: throbber.py,v 1.1.2.6 2003/02/26 18:38:14 RD Exp $
#

import threading, os
from wxPython.wx import *

# ------------------------------------------------------------------------------

wxEVT_UPDATE_THROBBER = wxNewEventType()
def EVT_UPDATE_THROBBER(win, func):
    win.Connect(-1, -1, wxEVT_UPDATE_THROBBER, func)

class UpdateThrobberEvent(wxPyEvent):
    def __init__(self):
        wxPyEvent.__init__(self)
        self.SetEventType(wxEVT_UPDATE_THROBBER)

# ------------------------------------------------------------------------------

class Throbber(wxPanel):
    """
    The first argument is either the name of a file that will be split into frames
    (a composite image) or a list of  strings of image names that will be treated
    as individual frames.  If a single (composite) image is given, then additional
    information must be provided: the number of frames in the image and the width
    of each frame.  The first frame is treated as the "at rest" frame (it is not
    shown during animation, but only when Throbber.Rest() is called.
    A second, single image may be optionally specified to overlay on top of the
    animation. A label may also be specified to show on top of the animation.
    """
    def __init__(self, parent, id,
                 bitmap,          # single (composite) bitmap or list of bitmaps
                 pos = wxDefaultPosition,
                 size = wxDefaultSize,
                 frameDelay = 0.1,# time between frames
                 frames = 0,      # number of frames (only necessary for composite image)
                 frameWidth = 0,  # width of each frame (only necessary for composite image)
                 label = None,    # optional text to be displayed
                 overlay = None,  # optional image to overlay on animation
                 reverse = 0,     # reverse direction at end of animation
                 style = 0,       # window style
                 name = "throbber"):
        wxPanel.__init__(self, parent, id, pos, size, style, name)
        self.name = name
        self.label = label
        _seqTypes = (type([]), type(()))

        # set size, guessing if necessary
        width, height = size
        if width == -1:
            if type(bitmap) in _seqTypes:
                width = bitmap[0].GetWidth()
            else:
                if frameWidth:
                    width = frameWidth
        if height == -1:
            if type(bitmap) in _seqTypes:
                height = bitmap[0].GetHeight()
            else:
                height = bitmap.GetHeight()
        self.width, self.height = width, height

        # double check it
        assert width != -1 and height != -1, "Unable to guess size"

        if label:
            extentX, extentY = self.GetTextExtent(label)
            self.labelX = (width - extentX)/2
            self.labelY = (height - extentY)/2
        self.frameDelay = frameDelay
        self.current = 0
        self.direction = 1
        self.autoReverse = reverse
        self.overlay = overlay
        if overlay is not None:
            self.overlay = overlay
            self.overlayX = (width - self.overlay.GetWidth()) / 2
            self.overlayY = (height - self.overlay.GetHeight()) / 2
        self.showOverlay = overlay is not None
        self.showLabel = label is not None

        # do we have a sequence of images?
        if type(bitmap) in _seqTypes:
            self.submaps = bitmap
            self.frames = len(self.submaps)
        # or a composite image that needs to be split?
        else:
            self.frames = frames
            self.submaps = []
            for chunk in range(frames):
                rect = (chunk * frameWidth, 0, width, height)
                self.submaps.append(bitmap.GetSubBitmap(rect))

        # self.sequence can be changed, but it's not recommended doing it
        # while the throbber is running.  self.sequence[0] should always
        # refer to whatever frame is to be shown when 'resting' and be sure
        # that no item in self.sequence >= self.frames or < 0!!!
        self.sequence = range(self.frames)

        self.SetClientSize((width, height))

        EVT_PAINT(self, self.OnPaint)
        EVT_UPDATE_THROBBER(self, self.Rotate)
        EVT_WINDOW_DESTROY(self, self.OnDestroyWindow)

        self.event = threading.Event()
        self.event.set() # we start out in the "resting" state


    def OnDestroyWindow(self, event):
        # this is currently broken due to a bug in wxWindows... hopefully
        # it'll be fixed soon.  Meanwhile be sure to explicitly call Stop()
        # before the throbber is destroyed.
        self.Stop()
        event.Skip()


    def Draw(self, dc):
        dc.DrawBitmap(self.submaps[self.sequence[self.current]], 0, 0, True)
        if self.overlay and self.showOverlay:
            dc.DrawBitmap(self.overlay, self.overlayX, self.overlayY, True)
        if self.label and self.showLabel:
            dc.DrawText(self.label, self.labelX, self.labelY)
            dc.SetTextForeground(wxWHITE)
            dc.DrawText(self.label, self.labelX-1, self.labelY-1)


    def OnPaint(self, event):
        self.Draw(wxPaintDC(self))
        event.Skip()


    def UpdateThread(self):
        try:
            while hasattr(self, 'event') and not self.event.isSet():
                wxPostEvent(self, UpdateThrobberEvent())
                self.event.wait(self.frameDelay)
        except wxPyDeadObjectError: # BUG: we were destroyed
            return


    def Rotate(self, event):
        if self.event.isSet():
            return
        self.current += self.direction
        if self.current >= len(self.sequence):
            if self.autoReverse:
                self.Reverse()
                self.current = len(self.sequence) - 1
            else:
                self.current = 1
        if self.current < 1:
            if self.autoReverse:
                self.Reverse()
                self.current = 1
            else:
                self.current = len(self.sequence) - 1
        self.Draw(wxClientDC(self))


    # --------- public methods ---------
    def SetFont(self, font):
        """Set the font for the label"""
        wxPanel.SetFont(self, font)
        self.SetLabel(self.label)
        self.Draw(wxClientDC(self))


    def Rest(self):
        """Stop the animation and return to frame 0"""
        self.Stop()
        self.current = 0
        self.Draw(wxClientDC(self))


    def Reverse(self):
        """Change the direction of the animation"""
        self.direction = -self.direction


    def Running(self):
        """Returns True if the animation is running"""
        return not self.event.isSet()


    def Start(self):
        """Start the animation"""
        if not self.Running():
            self.event.clear()
            thread = threading.Thread(target = self.UpdateThread,
                                      name = "%s-thread" % self.name)
            thread.start()


    def Stop(self):
        """Stop the animation"""
        if self.event.isSet():
            return
        self.event.set()


    def SetFrameDelay(self, frameDelay = 0.05):
        """Delay between each frame"""
        self.frameDelay = frameDelay


    def ToggleOverlay(self, state = None):
        """Toggle the overlay image"""
        if state is None:
            self.showOverlay = not self.showOverlay
        else:
            self.showOverlay = state
        self.Draw(wxClientDC(self))


    def ToggleLabel(self, state = None):
        """Toggle the label"""
        if state is None:
            self.showLabel = not self.showLabel
        else:
            self.showLabel = state
        self.Draw(wxClientDC(self))


    def SetLabel(self, label):
        """Change the text of the label"""
        self.label = label
        if label:
            extentX, extentY = self.GetTextExtent(label)
            self.labelX = (self.width - extentX)/2
            self.labelY = (self.height - extentY)/2
        self.Draw(wxClientDC(self))



# ------------------------------------------------------------------------------





# images converted with wxPython's img2py.py tool

from wxPython.wx import wxImageFromStream, wxBitmapFromImage
import cStringIO

##----------- Common Functions

def GetBitmap(ImageData):
    return wxBitmapFromImage(GetImage(ImageData))

def GetImage(ImageData):
    stream = cStringIO.StringIO(ImageData)
    return wxImageFromStream(stream)

##----------- Image Data

EofImageData = \
'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x07\x00\x00\x00\x07\x08\x06\
\x00\x00\x00\xc4RW\xd3\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\
\x00:IDATx\x9c]\x8e\xc1\r\x000\x08\x02\xc5\tn\xff)\xdd\xa0}\xd1`\xf9(\x9c\t\
\n(kf\x0e \xfbN\x90\xf3\xc1\x0c\xd2\xab\xaa\x16Huv\xa4\x00\xb5\x97\x1f\xac\
\x87\x1c\xe4\xe1\x05`2\x15\x9e\xc54\xca\xb4\x00\x00\x00\x00IEND\xaeB`\x82'







#----------------------------------------------------------------------------
# Name:        wxPython.lib.mixins.listctrl
# Purpose:     Helpful mix-in classes for wxListCtrl
#
# Author:      Robin Dunn
#
# Created:     15-May-2001
# RCS-ID:      $Id: listctrl.py,v 1.7.2.2 2003/01/10 00:06:55 RD Exp $
# Copyright:   (c) 2001 by Total Control Software
# Licence:     wxWindows license
#----------------------------------------------------------------------------

from wxPython.wx import *
import locale

#----------------------------------------------------------------------------

class wxColumnSorterMixin:
    """
    A mixin class that handles sorting of a wxListCtrl in REPORT mode when
    the column header is clicked on.

    There are a few requirments needed in order for this to work genericly:

      1. The combined class must have a GetListCtrl method that
         returns the wxListCtrl to be sorted, and the list control
         must exist at the time the wxColumnSorterMixin.__init__
         method is called because it uses GetListCtrl.

      2. Items in the list control must have a unique data value set
         with list.SetItemData.

      3. The combined class must have an attribute named itemDataMap
         that is a dictionary mapping the data values to a sequence of
         objects representing the values in each column.  These values
         are compared in the column sorter to determine sort order.

    Interesting methods to override are GetColumnSorter,
    GetSecondarySortValues, and GetSortImages.  See below for details.
    """

    def __init__(self, numColumns):
        self._colSortFlag = [0] * numColumns
        self._col = -1

        list = self.GetListCtrl()
        if not list:
            raise ValueError, "No wxListCtrl available"
        EVT_LIST_COL_CLICK(list, list.GetId(), self.__OnColClick)


    def SortListItems(self, col=-1, ascending=1):
        """Sort the list on demand.  Can also be used to set the sort column and order."""
        oldCol = self._col
        if col != -1:
            self._col = col
            self._colSortFlag[col] = ascending
        self.GetListCtrl().SortItems(self.GetColumnSorter())
        self.__updateImages(oldCol)


    def GetColumnWidths(self):
        """
        Returns a list of column widths.  Can be used to help restore the current
        view later.
        """
        list = self.GetListCtrl()
        rv = []
        for x in range(len(self._colSortFlag)):
            rv.append(list.GetColumnWidth(x))
        return rv


    def GetSortImages(self):
        """
        Returns a tuple of image list indexesthe indexes in the image list for an image to be put on the column
        header when sorting in descending order.
        """
        return (-1, -1)  # (decending, ascending) image IDs


    def GetColumnSorter(self):
        """Returns a callable object to be used for comparing column values when sorting."""
        return self.__ColumnSorter


    def GetSecondarySortValues(self, col, key1, key2):
        """Returns a tuple of 2 values to use for secondary sort values when the
           items in the selected column match equal.  The default just returns the
           item data values."""
        return (key1, key2)


    def __OnColClick(self, evt):
        oldCol = self._col
        self._col = col = evt.GetColumn()
        self._colSortFlag[col] = not self._colSortFlag[col]
        self.GetListCtrl().SortItems(self.GetColumnSorter())
        self.__updateImages(oldCol)
        evt.Skip()


    def __ColumnSorter(self, key1, key2):
        col = self._col
        ascending = self._colSortFlag[col]
        item1 = self.itemDataMap[key1][col]
        item2 = self.itemDataMap[key2][col]

        #--- Internationalization of string sorting with locale module
        if type(item1) == type('') or type(item2) == type(''):
            cmpVal = locale.strcoll(str(item1), str(item2))
        else:
            cmpVal = cmp(item1, item2)
        #---

        # If the items are equal then pick something else to make the sort value unique
        if cmpVal == 0:
            cmpVal = apply(cmp, self.GetSecondarySortValues(col, key1, key2))

        if ascending:
            return cmpVal
        else:
            return -cmpVal


    def __updateImages(self, oldCol):
        sortImages = self.GetSortImages()
        if self._col != -1 and sortImages[0] != -1:
            img = sortImages[self._colSortFlag[self._col]]
            list = self.GetListCtrl()
            if oldCol != -1:
                list.ClearColumnImage(oldCol)
            list.SetColumnImage(self._col, img)


#----------------------------------------------------------------------------
#----------------------------------------------------------------------------

class wxListCtrlAutoWidthMixin:
    """ A mix-in class that automatically resizes the last column to take up
        the remaining width of the wxListCtrl.

        This causes the wxListCtrl to automatically take up the full width of
        the list, without either a horizontal scroll bar (unless absolutely
        necessary) or empty space to the right of the last column.

        NOTE:    This only works for report-style lists.

        WARNING: If you override the EVT_SIZE event in your wxListCtrl, make
                 sure you call event.Skip() to ensure that the mixin's
                 _OnResize method is called.

        This mix-in class was written by Erik Westra <ewestra@wave.co.nz>
"""
    def __init__(self):
        """ Standard initialiser.
        """
        self._lastColMinWidth = None

        EVT_SIZE(self, self._onResize)
        EVT_LIST_COL_END_DRAG(self, self.GetId(), self._onResize)


    def resizeLastColumn(self, minWidth):
        """ Resize the last column appropriately.

            If the list's columns are too wide to fit within the window, we use
            a horizontal scrollbar.  Otherwise, we expand the right-most column
            to take up the remaining free space in the list.

            This method is called automatically when the wxListCtrl is resized;
            you can also call it yourself whenever you want the last column to
            be resized appropriately (eg, when adding, removing or resizing
            columns).

            'minWidth' is the preferred minimum width for the last column.
        """
        self._lastColMinWidth = minWidth
        self._doResize()

    # =====================
    # == Private Methods ==
    # =====================

    def _onResize(self, event):
        """ Respond to the wxListCtrl being resized.

            We automatically resize the last column in the list.
        """
        wxCallAfter(self._doResize)
        event.Skip()


    def _doResize(self):
        """ Resize the last column as appropriate.

            If the list's columns are too wide to fit within the window, we use
            a horizontal scrollbar.  Otherwise, we expand the right-most column
            to take up the remaining free space in the list.

            We remember the current size of the last column, before resizing,
            as the preferred minimum width if we haven't previously been given
            or calculated a minimum width.  This ensure that repeated calls to
            _doResize() don't cause the last column to size itself too large.
        """
        numCols = self.GetColumnCount()
        if numCols == 0: return # Nothing to resize.

        if self._lastColMinWidth == None:
            self._lastColMinWidth = self.GetColumnWidth(numCols - 1)

        # We're showing the vertical scrollbar -> allow for scrollbar width
        # NOTE: on GTK, the scrollbar is included in the client size, but on
        # Windows it is not included
        listWidth = self.GetClientSize().width
        if wxPlatform != '__WXMSW__':
            if self.GetItemCount() > self.GetCountPerPage():
                scrollWidth = wxSystemSettings_GetSystemMetric(wxSYS_VSCROLL_X)
                listWidth = listWidth - scrollWidth

        totColWidth = 0 # Width of all columns except last one.
        for col in range(numCols-1):
            totColWidth = totColWidth + self.GetColumnWidth(col)

        lastColWidth = self.GetColumnWidth(numCols - 1)

        if totColWidth + self._lastColMinWidth > listWidth:
            # We haven't got the width to show the last column at its minimum
            # width -> set it to its minimum width and allow the horizontal
            # scrollbar to show.
            self.SetColumnWidth(numCols-1, self._lastColMinWidth)
            return

        # Resize the last column to take up the remaining available space.

        self.SetColumnWidth(numCols-1, listWidth - totColWidth)



#----------------------------------------------------------------------------

SEL_FOC = wxLIST_STATE_SELECTED | wxLIST_STATE_FOCUSED
def selectBeforePopup(event):
    """Ensures the item the mouse is pointing at is selected before a popup.

    Works with both single-select and multi-select lists."""
    ctrl = event.GetEventObject()
    if isinstance(ctrl, wxListCtrl):
        n, flags = ctrl.HitTest(event.GetPosition())
        if n >= 0:
            if not ctrl.GetItemState(n, wxLIST_STATE_SELECTED):
                for i in range(ctrl.GetItemCount()):
                    ctrl.SetItemState(i, 0, SEL_FOC)
                #for i in getListCtrlSelection(ctrl, SEL_FOC):
                #    ctrl.SetItemState(i, 0, SEL_FOC)
                ctrl.SetItemState(n, SEL_FOC, SEL_FOC)

def getListCtrlSelection(listctrl, state=wxLIST_STATE_SELECTED):
    """ Returns list of item indexes of given state (selected by defaults) """
    res = []
    idx = -1
    while 1:
        idx = listctrl.GetNextItem(idx, wxLIST_NEXT_ALL, state)
        if idx == -1:
            break
        res.append(idx)
    return res

class ListCtrlSelectionManagerMix:
    """Mixin that defines a platform independent selection policy

    As selection single and multi-select list return the item index or a
    list of item indexes respectively.
    """
    wxEVT_DOPOPUPMENU = wxNewId()
    _menu = None

    def __init__(self):
        EVT_RIGHT_DOWN(self, self.OnLCSMRightDown)
        self.Connect(-1, -1, self.wxEVT_DOPOPUPMENU, self.OnLCSMDoPopup)

    def getPopupMenu(self):
        """ Override to implement dynamic menus (create) """
        return self._menu

    def setPopupMenu(self, menu):
        """ Must be set for default behaviour """
        self._menu = menu

    def afterPopupMenu(self, menu):
        """ Override to implement dynamic menus (destroy) """
        pass

    def getSelection(self):
        res = getListCtrlSelection(self)
        if self.GetWindowStyleFlag() & wxLC_SINGLE_SEL:
            if res:
                return res[0]
            else:
                return -1
        else:
            return res

    def OnLCSMRightDown(self, event):
        selectBeforePopup(event)
        event.Skip()
        menu = self.getPopupMenu()
        if menu:
            evt = wxPyEvent()
            evt.SetEventType(self.wxEVT_DOPOPUPMENU)
            evt.menu = menu
            evt.pos = event.GetPosition()
            wxPostEvent(self, evt)

    def OnLCSMDoPopup(self, event):
        self.PopupMenu(event.menu, event.pos)
        self.afterPopupMenu(event.menu)

#----------------------------------------------------------------------
